==> cssadmin_1.0.0.tar.gz: cssadmin/admin/cssadmin_save.php <==
<?php
//  ------------------------------------------------------------------------ //
//                   This module; Copyright (c) 2005 gusagi                  //
//                        <http://good-tea.ddo.jp/trpg>                      //
//  ------------------------------------------------------------------------ //

//*****************************************************************************/
// 
//*****************************************************************************/
require_once( dirname(dirname(__FILE__)) .'/init.php' );
include_once( XOOPS_ROOT_PATH .'/modules/system/constants.php' ) ;
require_once( $mod_path .'/include/gtickets.php' );
require_once( $mod_path .'/language/' .$xoopsConfig['language'] .'/modinfo.php' );
require_once( $mod_path .'/language/' .$xoopsConfig['language'] .'/admin.php' );

// check access right (needs system_admin of BLOCK)
$sysperm_handler =& xoops_gethandler('groupperm');
if (!$sysperm_handler->checkRight('system_admin', XOOPS_SYSTEM_BLOCK, $xoopsUser->getGroups())) redirect_header( XOOPS_URL.'/user.php' , 1 , _NOPERM ) ;

// 󥿥åȤγǧ
if ( ! $xoopsGTicket->check($post = true, $mod_name) ) {
	redirect_header( $mod_url.'/', 3, $xoopsGTicket->getErrors() );
	exit;
}

// MyTextSanitizer󥹥󥹤
$myts =& MyTextSanitizer::getInstance();

// å¸ߤʤӽ
if ( empty($_SESSION['cssadmin_op']) ) {
	redirect_header( XOOPS_URL, 2, _AM_CSSADMIN_ERR_ILLEGITIMATE_OP );
	exit;
}
// $opͤξӽ
if ( $_SESSION['cssadmin_op'] !== 'save_modules_css' && 
	$_SESSION['cssadmin_op'] !== 'save_blocks_css' && 
	$_SESSION['cssadmin_op'] !== 'delete_trash_css' ) {
	redirect_header( XOOPS_URL, 2, _AM_CSSADMIN_ERR_ILLEGITIMATE_OP );
	exit;
}

// åμ
$op = $_SESSION['cssadmin_op'];

// ѿν
$sql = '';
$redirect = '';
//*****************************************************************************/
// β̤ξsql
//*****************************************************************************/
// ⥸塼CSS
if ( $op === 'save_modules_css' ) {
	// 쥯
	$redirect = $mod_url .'/admin/cssadmin_modules.php';
	// åμ
	$modules = array();
	$modules = $_SESSION['cssadmin_modules'];
	$cssadmin_modules = $xoopsDB->prefix( 'cssadmin_modules' );
	foreach( $modules as $key => $module) {
		$mid = intval( $module['mid'] );
		if ( ! empty($module['ucfirstname']) ) {
			$module_css_field = $module['ucfirstname'] .'ModuleCss';
			$css = $myts->addslashes($myts->stripSlashesGPC(basename($_POST[$module_css_field])) );
			// cssեʸĹå
			if ( strlen($css) > $css_max_length ) {
					redirect_header( $redirect, 2, sprintf(_AM_CSSADMIN_ERR_CSS_TOO_LONG, $css_max_length) );
					exit;
			}
			// Ͽ
			if ( empty($module['selected']) && !empty($_POST[$module_css_field]) ) {
				$sql = "INSERT INTO $cssadmin_modules";
				$sql .= " VALUES( $mid, '$css' )";
				$result = $xoopsDB->query( $sql );
				if ( ! $result ) {
					redirect_header( $redirect, 2, _AM_CSSADMIN_ERR_FAILED_DB_UPDATE );
					exit;
				}
			// CSSϢդѹ
			} elseif ( !empty($module['selected']) && !empty($_POST[$module_css_field]) 
					&& ($module['selected'] !== $_POST[$module_css_field]) ) {
				$sql = "UPDATE $cssadmin_modules SET ";
				$sql .= " css = '$css'";
				$sql .= " WHERE mid = $mid";
				$result = $xoopsDB->query( $sql );
				if ( ! $result ) {
					redirect_header( $redirect, 2, _AM_CSSADMIN_ERR_FAILED_DB_UPDATE );
					exit;
				}
			// CSSϢդѻ߻
			} elseif ( !empty($module['selected']) && empty($_POST[$module_css_field]) ) {
				$sql = "DELETE FROM $cssadmin_modules";
				$sql .= " WHERE mid = $mid";
				$result = $xoopsDB->query( $sql );
				if ( ! $result ) {
					redirect_header( $redirect, 2, _AM_CSSADMIN_ERR_FAILED_DB_UPDATE );
					exit;
				}
			}
		}
	}
	// ơ֥κŬԤ
	$sql = "OPTIMIZE TABLE $cssadmin_modules";
	$xoopsDB->query( $sql );
// ֥åCSS
} elseif ( $op === 'save_blocks_css' ) {
	$redirect = $mod_url .'/admin/cssadmin_blocks.php';
	include_once( dirname(__FILE__) .'/mycssadmin_save.php' );
} elseif ( $op === 'delete_trash_css' ) {
	// ơ֥̾
	$cssadmin_modules = $xoopsDB->prefix( 'cssadmin_modules' );
	$cssadmin_blocks = $xoopsDB->prefix( 'cssadmin_blocks' );
	// 쥯
	$redirect = $mod_url .'/admin/index.php';
	// 󥤥󥹥ȡ뤵줿⥸塼˴ؤ
	$del_modules = array();
	$del_modules = $_SESSION['cssadmin_del_modules'];
	foreach( $del_modules as $key => $mid) {
		// ⥸塼CSSκ
		$sql = "DELETE FROM $cssadmin_modules";
		$sql .= " WHERE mid = $mid";
		$result = $xoopsDB->query( $sql );
		if ( ! $result ) {
			redirect_header( $redirect, 2, _AM_CSSADMIN_ERR_FAILED_DB_UPDATE );
			exit;
		}
	}
	// 줿֥å˴ؤ
	$del_blocks = array();
	$del_blocks = $_SESSION['cssadmin_del_blocks'];
	foreach( $del_blocks as $key => $bid) {
		// ֥åCSSκ
		$sql = "DELETE FROM $cssadmin_blocks";
		$sql .= " WHERE bid = $bid";
		$result = $xoopsDB->query( $sql );
		if ( ! $result ) {
			redirect_header( $redirect, 2, _AM_CSSADMIN_ERR_FAILED_DB_UPDATE );
			exit;
		}
	}
	// ơ֥κŬԤ
	$sql = "OPTIMIZE TABLE $cssadmin_modules";
	$xoopsDB->query( $sql );
	// ơ֥κŬԤ
	$sql = "OPTIMIZE TABLE $cssadmin_blocks";
	$xoopsDB->query( $sql );
}

//*****************************************************************************/
// λ
//*****************************************************************************/ 
// åΥꥢ
unset( $_SESSION['cssadmin_modules'] );
unset( $_SESSION['cssadmin_del_modules'] );
unset( $_SESSION['cssadmin_del_blocks'] );
// ⥸塼CSS̤
redirect_header( $redirect, 2, _AM_CSSADMIN_COPMLETE_DATA_UPDATE );
exit;

?>

==> cssadmin_1.0.4.tar.gz: cssadmin/admin/cssadmin_save.php <==
<?php
//  ------------------------------------------------------------------------ //
//                   This module; Copyright (c) 2005 gusagi                  //
//                        <http://good-tea.ddo.jp/trpg>                      //
//  ------------------------------------------------------------------------ //

//*****************************************************************************/
// 
//*****************************************************************************/
require_once( dirname(dirname(__FILE__)) .'/init.php' );
include_once( XOOPS_ROOT_PATH .'/modules/system/constants.php' ) ;
require_once( $mod_path .'/include/gtickets.php' );
require_once( $mod_path .'/language/' .$xoopsConfig['language'] .'/modinfo.php' );
require_once( $mod_path .'/language/' .$xoopsConfig['language'] .'/admin.php' );

// check access right (needs system_admin of BLOCK)
$sysperm_handler =& xoops_gethandler('groupperm');
if (!$sysperm_handler->checkRight('system_admin', XOOPS_SYSTEM_BLOCK, $xoopsUser->getGroups())) redirect_header( XOOPS_URL.'/user.php' , 1 , _NOPERM ) ;

// 󥿥åȤγǧ
if ( ! $xoopsGTicket->check($post = true, $mod_name) ) {
	redirect_header( $mod_url.'/', 3, $xoopsGTicket->getErrors() );
	exit;
}

// MyTextSanitizer󥹥󥹤
$myts =& MyTextSanitizer::getInstance();

// å¸ߤʤӽ
if ( empty($_SESSION['cssadmin_op']) ) {
	redirect_header( XOOPS_URL, 2, _AM_CSSADMIN_ERR_ILLEGITIMATE_OP );
	exit;
}
// $opͤξӽ
if ( $_SESSION['cssadmin_op'] !== 'save_modules_css' && 
	$_SESSION['cssadmin_op'] !== 'save_blocks_css' && 
	$_SESSION['cssadmin_op'] !== 'delete_trash_css' ) {
	redirect_header( XOOPS_URL, 2, _AM_CSSADMIN_ERR_ILLEGITIMATE_OP );
	exit;
}

// åμ
$op = $_SESSION['cssadmin_op'];

// ѿν
$sql = '';
$redirect = '';
//*****************************************************************************/
// β̤ξsql
//*****************************************************************************/
// ⥸塼CSS
if ( $op === 'save_modules_css' ) {
	// 쥯
	$redirect = $mod_url .'/admin/cssadmin_modules.php';
	// åμ
	$modules = array();
	$modules = $_SESSION['cssadmin_modules'];
	$cssadmin_modules = $xoopsDB->prefix( 'cssadmin_modules' );
	foreach( $modules as $key => $module) {
		$mid = intval( $module['mid'] );
		if ( ! empty($module['ucfirstname']) ) {
			$module_css_field = $module['ucfirstname'] .'ModuleCss';
			$css = !empty( $_POST[$module_css_field] ) ?
				addslashes( $myts->stripSlashesGPC(basename($_POST[$module_css_field])) ) : '';
			// cssեʸĹå
			if ( strlen($css) > $css_max_length ) {
					redirect_header( $redirect, 2, sprintf(_AM_CSSADMIN_ERR_CSS_TOO_LONG, $css_max_length) );
					exit;
			}
			// Ͽ
			if ( empty($module['selected']) && !empty($css) ) {
				$sql = "INSERT INTO $cssadmin_modules";
				$sql .= " VALUES( $mid, '$css' )";
				$result = $xoopsDB->query( $sql );
				if ( ! $result ) {
					redirect_header( $redirect, 2, _AM_CSSADMIN_ERR_FAILED_DB_UPDATE );
					exit;
				}
			// CSSϢդѹ
			} elseif ( !empty($module['selected']) && !empty($css) 
					&& ($module['selected'] !== $css) ) {
				$sql = "UPDATE $cssadmin_modules SET ";
				$sql .= " css = '$css'";
				$sql .= " WHERE mid = $mid";
				$result = $xoopsDB->query( $sql );
				if ( ! $result ) {
					redirect_header( $redirect, 2, _AM_CSSADMIN_ERR_FAILED_DB_UPDATE );
					exit;
				}
			// CSSϢդѻ߻
			} elseif ( !empty($module['selected']) && empty($css) ) {
				$sql = "DELETE FROM $cssadmin_modules";
				$sql .= " WHERE mid = $mid";
				$result = $xoopsDB->query( $sql );
				if ( ! $result ) {
					redirect_header( $redirect, 2, _AM_CSSADMIN_ERR_FAILED_DB_UPDATE );
					exit;
				}
			}
		}
	}
	// ơ֥κŬԤ
	$sql = "OPTIMIZE TABLE $cssadmin_modules";
	$xoopsDB->query( $sql );
// ֥åCSS
} elseif ( $op === 'save_blocks_css' ) {
	$redirect = $mod_url .'/admin/cssadmin_blocks.php';
	include_once( dirname(__FILE__) .'/mycssadmin_save.php' );
} elseif ( $op === 'delete_trash_css' ) {
	// ơ֥̾
	$cssadmin_modules = $xoopsDB->prefix( 'cssadmin_modules' );
	$cssadmin_blocks = $xoopsDB->prefix( 'cssadmin_blocks' );
	// 쥯
	$redirect = $mod_url .'/admin/index.php';
	// 󥤥󥹥ȡ뤵줿⥸塼˴ؤ
	$del_modules = array();
	$del_modules = $_SESSION['cssadmin_del_modules'];
	foreach( $del_modules as $key => $mid) {
		// ⥸塼CSSκ
		$sql = "DELETE FROM $cssadmin_modules";
		$sql .= " WHERE mid = $mid";
		$result = $xoopsDB->query( $sql );
		if ( ! $result ) {
			redirect_header( $redirect, 2, _AM_CSSADMIN_ERR_FAILED_DB_UPDATE );
			exit;
		}
	}
	// 줿֥å˴ؤ
	$del_blocks = array();
	$del_blocks = $_SESSION['cssadmin_del_blocks'];
	foreach( $del_blocks as $key => $bid) {
		// ֥åCSSκ
		$sql = "DELETE FROM $cssadmin_blocks";
		$sql .= " WHERE bid = $bid";
		$result = $xoopsDB->query( $sql );
		if ( ! $result ) {
			redirect_header( $redirect, 2, _AM_CSSADMIN_ERR_FAILED_DB_UPDATE );
			exit;
		}
	}
	// ơ֥κŬԤ
	$sql = "OPTIMIZE TABLE $cssadmin_modules";
	$xoopsDB->query( $sql );
	// ơ֥κŬԤ
	$sql = "OPTIMIZE TABLE $cssadmin_blocks";
	$xoopsDB->query( $sql );
}

//*****************************************************************************/
// λ
//*****************************************************************************/ 
// åΥꥢ
unset( $_SESSION['cssadmin_modules'] );
unset( $_SESSION['cssadmin_del_modules'] );
unset( $_SESSION['cssadmin_del_blocks'] );
// ⥸塼CSS̤
redirect_header( $redirect, 2, _AM_CSSADMIN_COPMLETE_DATA_UPDATE );
exit;

?>
